@@ -44,7 +44,7 @@ knit_ex <- function(x, ..., quiet = TRUE, open = FALSE){
     }
     x <- paste0(x, collapse = "\n")
     if( any(html_chunks) ){
-        res <- knitr::knit2html(text = x, ..., fragment.only = TRUE, quiet = quiet)
+        res <- knitr::knit2html(text = x, ..., template = FALSE, quiet = quiet)
         if( open ){
             tmp <- tempfile("knit_ex", fileext = '.html')
             cat(res, file = tmp, sep = "\n") 
@@ -80,6 +80,7 @@ try_message <- function(signal = FALSE){
 #' @param options list of current knitr chunk options 
 #' @param envir environment where the chunk is evaluated
 #' 
+#' @return * `hook_try` returns a function.
 #' @export
 #' @examples
 #' 
@@ -91,6 +92,7 @@ try_message <- function(signal = FALSE){
 #' # with try the error is output on stderr but not caughted by knitr
 #' knit_ex("try( stop('ah ah') )")
 #' 
+#' \donttest{
 #' # no message caught
 #' knit_ex("
 #' ^^^{r, include = FALSE}
@@ -100,6 +102,7 @@ try_message <- function(signal = FALSE){
 #' ^^^{r, try=TRUE}
 #' try( stop('ah ah') )
 #' ^^^")
+#' }
 #' 
 hook_try <- local({
     .try_defined <- FALSE
@@ -172,10 +175,12 @@ chunkOutputHook <- function(name, hook, type = c('output', 'source', 'chunk')){
 #' characters in the output (e.g., as used in progress bars), and still 
 #' obtain a final output as in the console.
 #' 
+#' @return * `hook_backspace` returns a function.
 #' @rdname knit_ex
 #' @export 
 #' @examples 
 #' 
+#' \donttest{
 #' # Correctly formatting backspaces in chunk outputs
 #' tmp <- tempfile(fileext = '.Rmd')
 #' cat(file = tmp, "
@@ -196,15 +201,21 @@ chunkOutputHook <- function(name, hook, type = c('output', 'source', 'chunk')){
 #' 
 #' # knit
 #' out <- knitr::knit2html(tmp, fragment.only = TRUE)
+#' 
+#' }
+#' 
 #' # look at output
 #' \dontrun{
 #'   browseURL(out)
 #'   edit( file = out)
 #' }
+#'
+#' \donttest{    
 #' # cleanup
 #' out_files <- list.files(dirname(out), full.names = TRUE,
 #'                          pattern = paste0("^", tools::file_path_sans_ext(out))) 
 #' unlink(c(tmp, out_files))
+#' }
 #' 
 #' 
 hook_backspace <- chunkOutputHook('backspace', 
@@ -222,6 +233,7 @@ hook_backspace <- chunkOutputHook('backspace',
 #'  
 #' \code{str_bs} was adapted from a proposal from Yihui Xie.
 #' 
+#' @return * `str_bs` returns a character string.
 #' @export
 #' @examples 
 #' 
@@ -354,12 +366,15 @@ $( document ).ready(function(){
 });
 </script>"
 
-#' @describeIn knit_ex is a chunk hook that adds clickable elements to toggle \emph{indvidual}
+#' @describeIn knit_ex a chunk hook that adds clickable elements to toggle \emph{indvidual}
 #' code chunks in HTML documents generated from .Rmd files.
 #' 
+#' @return * `hook_toggle`: returns a hook function.
 #' @export
 #' @examples
 #' 
+#' \donttest{
+#' 
 #' knit_ex("
 #' 
 #' Declare chunk hook:
@@ -391,12 +406,14 @@ $( document ).ready(function(){
 #' sample(5)
 #' ^^^
 #' 
-#' To diable the toggle link, one can pass anything except TRUE/FALSE:
+#' To disable the toggle link, one can pass anything except TRUE/FALSE:
 #' ^^^{r, toggle = NA}
 #' sample(5)
 #' ^^^
 #' 
-#' ", open = TRUE)
+#' ", open = FALSE)
+#' 
+#' }
 #' 
 hook_toggle <- function(){
     .init <- TRUE
@@ -422,7 +439,7 @@ hook_toggle <- function(){
             .last_label <<- label
             subst <- paste0("<a href=\"\" onclick=\"toggle_vis2('", id, "'); return false;\">Show/Hide R code</a>\n", subst)
         }
-        sub("```([^\n]*)\n", sprintf(subst, 'block'), x)
+        sub("```([^\n]*)\n", subst, x)
     })
     fn()
 }
@@ -543,6 +560,7 @@ parse_yaml_front_matter2 <- local({
 #' home directory, or, if missing, for a yaml section \code{rmarkdown::render} 
 #' in the user's R profile.
 #' 
+#' @return the path to the rendered file, like [rmarkdown::render].
 #' @seealso \code{\link{read.yaml_section}}
 #' @export
 render_notes <- function(input, output_format = NULL, output_options = NULL, ..., .config = NULL){
